[![pypi](https://img.shields.io/pypi/v/lnschema_wetlab?color=%2334D058&label=pypi%20package)](https://pypi.org/project/lnschema_wetlab)

# lnschema-wetlab: Generic bio wetlab (`vvhc`)

Read the [docs](https://lamin.ai/docs/lnschema-wetlab).
